@@ -167,7 +167,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
 
         return r
 
-    def dataset(self, slug):
+    def set_current_dataset(self, slug):
         """
         set in the agent object the properties of specific dataset
 
@@ -670,7 +670,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         s.mount('https://', HTTPAdapter(max_retries=retries))
         r = s.get(url=url, headers=self._headers)
         r.raise_for_status()
-        if (r != None and r.json() != []):
+        if (r.json() != []):
             if(multiple):
                 user_ids = []
                 for user in r.json()[0]:
@@ -738,7 +738,6 @@ class Agent(Insight, Channel, Catalog, Dataset):
         authentication_url = self._base_url_askdata + "/smartfeed/channels/{}/users".format(channel_id)
         r = s.post(url=authentication_url, headers=self._headers, json=data)
         r.raise_for_status()
-        #return r
 
 
     def get_channel(self, channel_code):
@@ -1162,8 +1161,7 @@ class Askdata(SignUp):
             for condition in join_conditions:
                 left_conditions.append(condition["left_on"])
                 right_conditions.append(condition["right_on"])
-            #left_conditions = self.__retrieve_og_columns(left_conditions, df)
-            #right_conditions = self.__retrieve_og_columns(right_conditions, df_query)
+
             return df.merge(df_query, how, None, left_conditions, right_conditions)
 
         return df.merge(df_query, how, on, left_on, right_on)
@@ -1325,10 +1323,9 @@ class Askdata(SignUp):
 
     def query(self, workspace='', dataset='', fields:list=[], filters=None, sorted_by=None, limit=50, offset=0, pivot=[], get_raw_data=False):
 
-        if (workspace == ''):
-            if ('/' in dataset):
-                workspace = dataset.split("/")[0]
-                dataset = dataset.split("/")[1]
+        if (workspace == '' and '/' in dataset):
+            workspace = dataset.split("/")[0]
+            dataset = dataset.split("/")[1]
 
         if(get_raw_data):
             return self.get("", workspace, dataset, fields=fields, filters=filters, sorted_by=sorted_by, limit=limit, offset=offset, pivot=pivot)
