@@ -1,6 +1,4 @@
 import pandas as pd
-import requests
-import json
 
 """ 
 Read google sheet as dataframe
